==> archive_210916_183109.zip: storage/framework/views/dfa99aadc76eb9b1549c6ce30c9bffa781e72c8a.php <==
<?php $__env->startSection('content'); ?>


         <div class="container mt-5 mb-5">
            <div class="row">
               <div class="col-lg-5 col-sm-12 col-12">
                  <div class="mendas-data text-center">
                    <img src="image/logo.png" height="200">
                     <h4 class="text-center mb-3"><?php echo e(__('Login')); ?></h4>
                     <p>Une prise &agrave; changer ? Une serrur &agrave; remplacer ? Un WC &agrave; changer ? Ne vous inqui&eacute;tez pas, Djo vous trouve une solution pour vos petits travaux &agrave; r&eacute;aliser &agrave; votre domicile. Pour effectuer votre demande rien de plus simple:</p>

                     <p class="mt-4">Vous &ecirc;tes un nouvel utillisateur?</p>
                     <a href="<?php echo e(route('register')); ?>">
                     <button class="btn-color">Inscrivez-vous
                     </button>
</a>

                     <p class="mt-3">Vous avez d&eacute;j&agrave; un comte</p>

                     <form method="POST" action="<?php echo e(route('login')); ?>">
                        <?php echo csrf_field(); ?>
                       <div class="form-group email-overlay">
                                <input id="email" type="email" class="form-text-field form-control <?php $__errorArgs = ['email'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>" name="email" value="<?php echo e(old('email')); ?>" required autocomplete="email" autofocus placeholder="<?php echo e(__('E-Mail Address')); ?>">
                         <i class="fas fa-envelope"></i>
                         <?php $__errorArgs = ['email'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                                    <span class="invalid-feedback" role="alert">
                                        <strong><?php echo e($message); ?></strong>
                                    </span>
                                <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                       </div>

                       <div class="form-group email-overlay">
                                <input id="password" type="password" class=" form-text-field form-control <?php $__errorArgs = ['password'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>" name="password" required autocomplete="current-password" placeholder="<?php echo e(__('Password')); ?>">
                         <i class="fas fa-lock"></i>
                         <?php $__errorArgs = ['password'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                                    <span class="invalid-feedback" role="alert">
                                        <strong><?php echo e($message); ?></strong>
                                    </span>
                                <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                       </div>
                       <div class="form-group">
                         <input class="form-check-input" type="checkbox" name="remember" id="remember" <?php echo e(old('remember') ? 'checked' : ''); ?>>

                                    <label class="form-check-label" for="remember">
                                        <?php echo e(__('Remember Me')); ?>

                                    </label>
                       </div>
                     <button type="submit" class="btn-color">
                                    <?php echo e(__('Login')); ?>

                                </button>
                                <?php if(Route::has('password.request')): ?>
                                    <a class="" href="<?php echo e(route('password.request')); ?>">
                                        <p class="mt-3"><span class="oc1"><strong>  <?php echo e(__('Forgot Your Password?')); ?></strong></span></p>
                                    </a>
                                <?php endif; ?>
                              
            
                            <?php if(Route::has('register')): ?>
                     <p class="mt-3"><a href="<?php echo e(route('register')); ?>"><span class="oc1"><strong>Cr&eacute;ez un compte</strong></span></a></p>
                     <?php endif; ?>
                     
                     </form>
                  </div>
               </div>
            </div>
         </div>

         <img src="<?php echo e(asset('image/PersonnageMécanicien.png')); ?>" class="comman-image-all5">
      </div>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH C:\xampp\htdocs\HelloDjo_Source\resources\views/auth/login.blade.php ENDPATH**/ ?>

==> archive_211019_102255.zip: storage/framework/views/dfa99aadc76eb9b1549c6ce30c9bffa781e72c8a.php <==
<?php $__env->startSection('content'); ?>


         <div class="container mt-5 mb-5">
            <div class="row">
               <div class="col-lg-5 col-sm-12 col-12">
                  <div class="mendas-data text-center">
                    <img src="image/logo.png" height="200">
                     <h4 class="text-center mb-3"><?php echo e(__('Login')); ?></h4>
                     <p>Une prise &agrave; changer ? Une serrur &agrave; remplacer ? Un WC &agrave; changer ? Ne vous inqui&eacute;tez pas, Djo vous trouve une solution pour vos petits travaux &agrave; r&eacute;aliser &agrave; votre domicile. Pour effectuer votre demande rien de plus simple:</p>

                     <p class="mt-4">Vous &ecirc;tes un nouvel utillisateur?</p>
                     <a href="<?php echo e(route('register')); ?>">
                     <button class="btn-color">Inscrivez-vous
                     </button>
</a>

                     <p class="mt-3">Vous avez d&eacute;j&agrave; un comte</p>

                     <form method="POST" action="<?php echo e(route('login')); ?>">
                        <?php echo csrf_field(); ?>
                       <div class="form-group email-overlay">
                                <input id="email" type="email" class="form-text-field form-control <?php $__errorArgs = ['email'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>" name="email" value="<?php echo e(old('email')); ?>" required autocomplete="email" autofocus placeholder="<?php echo e(__('E-Mail Address')); ?>">
                         <i class="fas fa-envelope"></i>
                         <?php $__errorArgs = ['email'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                                    <span class="invalid-feedback" role="alert">
                                        <strong><?php echo e($message); ?></strong>
                                    </span>
                                <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                       </div>

                       <div class="form-group email-overlay">
                                <input id="password" type="password" class=" form-text-field form-control <?php $__errorArgs = ['password'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?> is-invalid <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>" name="password" required autocomplete="current-password" placeholder="<?php echo e(__('Password')); ?>">
                         <i class="fas fa-lock"></i>
                         <?php $__errorArgs = ['password'];
$__bag = $errors->getBag($__errorArgs[1] ?? 'default');
if ($__bag->has($__errorArgs[0])) :
if (isset($message)) { $__messageOriginal = $message; }
$message = $__bag->first($__errorArgs[0]); ?>
                                    <span class="invalid-feedback" role="alert">
                                        <strong><?php echo e($message); ?></strong>
                                    </span>
                                <?php unset($message);
if (isset($__messageOriginal)) { $message = $__messageOriginal; }
endif;
unset($__errorArgs, $__bag); ?>
                       </div>
                       <div class="form-group">
                         <input class="form-check-input" type="checkbox" name="remember" id="remember" <?php echo e(old('remember') ? 'checked' : ''); ?>>

                                    <label class="form-check-label" for="remember">
                                        <?php echo e(__('Remember Me')); ?>

                                    </label>
                       </div>
                     <button type="submit" class="btn-color">
                                    <?php echo e(__('Login')); ?>

                                </button>
                                <?php if(Route::has('password.request')): ?>
                                    <a class="" href="<?php echo e(route('password.request')); ?>">
                                        <p class="mt-3"><span class="oc1"><strong>  <?php echo e(__('Forgot Your Password?')); ?></strong></span></p>
                                    </a>
                                <?php endif; ?>
                              
            
                            <?php if(Route::has('register')): ?>
                     <p class="mt-3"><a href="<?php echo e(route('register')); ?>"><span class="oc1"><strong>Cr&eacute;ez un compte</strong></span></a></p>
                     <?php endif; ?>
                     
                     </form>
                  </div>
               </div>
            </div>
         </div>

         <img src="<?php echo e(asset('image/PersonnageMecanicien.png')); ?>" class="comman-image-all5">
      </div>

<?php $__env->stopSection(); ?>

<?php echo $__env->make('layouts.app', \Illuminate\Support\Arr::except(get_defined_vars(), ['__data', '__path']))->render(); ?><?php /**PATH C:\xampp\htdocs\HelloDjo_Source\resources\views/auth/login.blade.php ENDPATH**/ ?>
